// COpenGLView.cpp : implementation of the COpenGLView class
//

#include "stdafx.h"
#include "OpenGL View Class.h"

#include "OpenGL View ClassDoc.h"
#include "COpenGLView.h"
#include "math.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif



const char* const COpenGLView::_ErrorStrings[]= {
				{"No Error"},					// 0
				{"Unable to get a DC"},			// 1
				{"ChoosePixelFormat failed"},	// 2
				{"SelectPixelFormat failed"},	// 3
				{"wglCreateContext failed"},	// 4
				{"wglMakeCurrent failed"},		// 5
				{"wglDeleteContext failed"},	// 6
				{"SwapBuffers failed"},			// 7

		};

/////////////////////////////////////////////////////////////////////////////
// COpenGLView

IMPLEMENT_DYNCREATE(COpenGLView, CView)

BEGIN_MESSAGE_MAP(COpenGLView, CView)
	//{{AFX_MSG_MAP(COpenGLView)
	ON_WM_CREATE()
	ON_WM_DESTROY()
	ON_WM_ERASEBKGND()
	ON_WM_SIZE()
	ON_WM_LBUTTONDBLCLK()
	ON_WM_LBUTTONUP()
	ON_WM_CANCELMODE()
	ON_WM_CAPTURECHANGED()
	ON_COMMAND(MENUHLS, OnMENUHLS)
	ON_UPDATE_COMMAND_UI(MENUHLS, OnUpdateMENUHLS)
	ON_COMMAND(MENUHSV, OnMENUHSV)
	ON_UPDATE_COMMAND_UI(MENUHSV, OnUpdateMENUHSV)
	ON_COMMAND(MENURGB, OnMENURGB)
	ON_UPDATE_COMMAND_UI(MENURGB, OnUpdateMENURGB)
	ON_COMMAND(ID_ROTATE, OnRotate)
	ON_UPDATE_COMMAND_UI(ID_ROTATE, OnUpdateRotate)
	ON_WM_LBUTTONDOWN()
	ON_WM_MOUSEMOVE()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// COpenGLView construction/destruction

COpenGLView::COpenGLView() :
	 m_hRC(0), m_pDC(0), m_ErrorString(_ErrorStrings[0])

{
	// TODO: add construction code here
	rotating=true;
	object=rgb;
	dragging=false;
	angle=20;

}

COpenGLView::~COpenGLView()
{
}

BOOL COpenGLView::PreCreateWindow(CREATESTRUCT& cs) 
{
	// TODO: Add your specialized code here and/or call the base class

	// An OpenGL window must be created with the following flags and must not
    // include CS_PARENTDC for the class style. 
    cs.style |= WS_CLIPSIBLINGS | WS_CLIPCHILDREN;
  	
	return CView::PreCreateWindow(cs);
}


/////////////////////////////////////////////////////////////////////////////
// COpenGLView drawing


void COpenGLView::OnDraw(CDC* pDC)
{
	COpenGLViewClassDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);

	// TODO: add draw code for native data here

	::glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );

	PreRenderScene();


	::glPushMatrix();
	RenderScene();
	::glPopMatrix();

	::glFinish();

	if ( FALSE == ::SwapBuffers( m_pDC->GetSafeHdc() ) )
		{
		SetError(7);
		}
	if(rotating){
		InvalidateRect(0,FALSE);
		GetParent()->PostMessage(WM_PAINT);
	}
}


/////////////////////////////////////////////////////////////////////////////
// COpenGLView diagnostics

#ifdef _DEBUG
void COpenGLView::AssertValid() const
{
	CView::AssertValid();
}

void COpenGLView::Dump(CDumpContext& dc) const
{
	CView::Dump(dc);
}

COpenGLViewClassDoc* COpenGLView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(COpenGLViewClassDoc)));
	return (COpenGLViewClassDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// COpenGLView message handlers

int COpenGLView::OnCreate(LPCREATESTRUCT lpCreateStruct) 
{
	if (CView::OnCreate(lpCreateStruct) == -1)
		return -1;
	
	// TODO: Add your specialized creation code here

	InitializeOpenGL();

	return 0;
}


/////////////////////////////////////////////////////////////////////////////
// GL helper functions

void COpenGLView::SetError( int e )
{
	// if there was no previous error,
	// then save this one
	if ( _ErrorStrings[0] == m_ErrorString ) 
		{
		m_ErrorString = _ErrorStrings[e];
		}
}


BOOL COpenGLView::InitializeOpenGL()
{
	// Can we put this in the constructor?
    m_pDC = new CClientDC(this);

    if ( NULL == m_pDC ) // failure to get DC
		{
		SetError(1);
		return FALSE;
		}

	if (!SetupPixelFormat())
		{
        return FALSE;
		}

    //n = ::GetPixelFormat(m_pDC->GetSafeHdc());
    //::DescribePixelFormat(m_pDC->GetSafeHdc(), n, sizeof(pfd), &pfd);

  //  CreateRGBPalette();

    if ( 0 == (m_hRC = ::wglCreateContext( m_pDC->GetSafeHdc() ) ) )
		{
		SetError(4);
		return FALSE;
		}

    if ( FALSE == ::wglMakeCurrent( m_pDC->GetSafeHdc(), m_hRC ) )
		{
		SetError(5);
		return FALSE;
		}	

	// specify black as clear color
    ::glClearColor( 1.0f, 1.0f, 1.0f, 0.0f );
	// specify the back of the buffer as clear depth
    ::glClearDepth( 1.0f );
	// enable depth testing
    ::glEnable( GL_DEPTH_TEST );

	return TRUE;
}


BOOL COpenGLView::SetupPixelFormat()
{
  static PIXELFORMATDESCRIPTOR pfd = 
	{
        sizeof(PIXELFORMATDESCRIPTOR),  // size of this pfd
        1,                              // version number
        PFD_DRAW_TO_WINDOW |            // support window
          PFD_SUPPORT_OPENGL |          // support OpenGL
          PFD_DOUBLEBUFFER,             // double buffered
        PFD_TYPE_RGBA,                  // RGBA type
        24,                             // 24-bit color depth
        0, 0, 0, 0, 0, 0,               // color bits ignored
        0,                              // no alpha buffer
        0,                              // shift bit ignored
        0,                              // no accumulation buffer
        0, 0, 0, 0,                     // accum bits ignored
//        32,                             // 32-bit z-buffer
		16,	// NOTE: better performance with 16-bit z-buffer
        0,                              // no stencil buffer
        0,                              // no auxiliary buffer
        PFD_MAIN_PLANE,                 // main layer
        0,                              // reserved
        0, 0, 0                         // layer masks ignored
    };
    int pixelformat;

    if ( 0 == (pixelformat = ::ChoosePixelFormat(m_pDC->GetSafeHdc(), &pfd)) )
	    {
		SetError(2);
        return FALSE;
		}

    if ( FALSE == ::SetPixelFormat(m_pDC->GetSafeHdc(), pixelformat, &pfd) )
	    {
       	SetError(3);
        return FALSE;
		}

    return TRUE;
}

void COpenGLView::OnDestroy() 
{
	CView::OnDestroy();
	
	// TODO: Add your message handler code here

    if ( FALSE == ::wglDeleteContext( m_hRC ) )
		{
		SetError(6);
 		}

    if ( m_pDC )
		{
        delete m_pDC;
		}
}


BOOL COpenGLView::OnEraseBkgnd( CDC* pDC ) 
{
	// TODO: Add your message handler code here and/or call default
	
	//	return CView::OnEraseBkgnd(pDC);
	return TRUE; // tell Windows not to erase the background
}

void COpenGLView::OnSize(UINT nType, int cx, int cy) 
{
	CView::OnSize(nType, cx, cy);
	
	// TODO: Add your message handler code here
	GLdouble aspect_ratio; // width/height ratio
	
	if ( 0 >= cx || 0 >= cy )
		{
		return;
		}


	SetupViewport( cx, cy );

	// select the projection matrix and clear it
    ::glMatrixMode( GL_PROJECTION );
    ::glLoadIdentity();

	// compute the aspect ratio
	// this will keep all dimension scales equal
	aspect_ratio = (GLdouble)cx/(GLdouble)cy;

	// select the viewing volumn
	SetupViewingFrustum( aspect_ratio );
	
	// switch back to the modelview matrix
    ::glMatrixMode( GL_MODELVIEW );
    ::glLoadIdentity();

	// now perform any viewing transformations
	SetupViewingTransform();
}

 /////////////////////////////////////////////////////////////////////////////
// COpenGLView helper functions

BOOL COpenGLView::SetupViewport( int cx, int cy )
{
	// select the full client area
    ::glViewport(0, 0, cx, cy);

	return TRUE;
}

BOOL COpenGLView::SetupViewingFrustum( GLdouble aspect_ratio )
{
	// select a default viewing volumn
    ::gluPerspective( 40.0f, aspect_ratio, .1f, 20.0f );
	return TRUE;
}


BOOL COpenGLView::SetupViewingTransform()
{
	// select a default viewing transformation
	// of a 20 degree rotation about the X axis
	// then a -5 unit transformation along Z
	::glTranslatef( 0.0f, 0.0f, -3.0f );

    return TRUE;
}


BOOL COpenGLView::RenderScene()
{
	
	::glRotatef(angle, 1.0f, 0.0f, 0.0f );
	

	//static int i=180;
	//glRotated(i,0,1,0);
	//i+=1;

	switch(object){
		case rgb: DrawRGB(); break;
		case hls: DrawHLS(); break;
		case hsv: DrawHSV(); break;
	}
	/*
*/
	

    return TRUE;
}	



void COpenGLView::OnLButtonDblClk(UINT nFlags, CPoint point) 
{
	// TODO: Add your message handler code here and/or call default

	CView::OnLButtonDblClk(nFlags, point);
}

void COpenGLView::OnLButtonUp(UINT nFlags, CPoint point) 
{

	dragging=false;	
	ReleaseCapture();
	CView::OnLButtonUp(nFlags, point);
}

void COpenGLView::OnCancelMode() 
{
	CView::OnCancelMode();
	
	// TODO: Add your message handler code here
	
}

void COpenGLView::OnCaptureChanged(CWnd *pWnd) 
{
	// TODO: Add your message handler code here

	
	CView::OnCaptureChanged(pWnd);
}

void COpenGLView::DrawHSV()
{

	static int i=180;
	glRotated(i,0,1,0);
	i+=1;

	GLfloat white[3]={0.0,0.5,0.0};
	GLfloat black[3]={0.0,-1.0,0.0};
	GLfloat red[3]={1.0,0.5,0.0};
	GLfloat yellow[3]={0.5,0.5,-0.866};
	GLfloat green[3]={-0.5,0.5,-0.866};
	GLfloat cyan[3]={-1.0,0.5,0.0};
	GLfloat blue[3]={-0.5,0.5,0.866};
	GLfloat magenta[3]={0.5,0.5,0.866};

	glBegin(GL_TRIANGLE_FAN);
	glColor3d(1,1,1);
	glVertex3fv(white);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glColor3d(1,1,0);
	glVertex3fv(yellow);
	glColor3d(0,1,0);
	glVertex3fv(green);
	glColor3d(0,1,1);
	glVertex3fv(cyan);
	glColor3d(0,0,1);
	glVertex3fv(blue);
	glColor3d(1,0,1);
	glVertex3fv(magenta);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glEnd();
	glBegin(GL_TRIANGLE_FAN);
	glColor3d(0,0,0);
	glVertex3fv(black);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glColor3d(1,1,0);
	glVertex3fv(yellow);
	glColor3d(0,1,0);
	glVertex3fv(green);
	glColor3d(0,1,1);
	glVertex3fv(cyan);
	glColor3d(0,0,1);
	glVertex3fv(blue);
	glColor3d(1,0,1);
	glVertex3fv(magenta);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glEnd();

	glScalef(1.005,1.005,1.005);
	glBegin(GL_LINE_STRIP);
	glColor3d(0,0,0);
	glVertex3fv(black);
	glVertex3fv(red);
	glVertex3fv(yellow);
	glVertex3fv(green);
	glVertex3fv(cyan);
	glVertex3fv(blue);
	glVertex3fv(magenta);
	glVertex3fv(red);
	glEnd();
	glBegin(GL_LINES);
	glVertex3fv(black);
	glVertex3fv(red);
	glVertex3fv(black);
	glVertex3fv(yellow);
	glVertex3fv(black);
	glVertex3fv(green);
	glVertex3fv(black);
	glVertex3fv(cyan);
	glVertex3fv(black);
	glVertex3fv(blue);
	glVertex3fv(white);
	glVertex3fv(red);
	glVertex3fv(white);
	glVertex3fv(yellow);
	glVertex3fv(white);
	glVertex3fv(cyan);
	glVertex3fv(white);
	glVertex3fv(green);
	glVertex3fv(white);
	glVertex3fv(blue);
	glVertex3fv(white);
	glVertex3fv(magenta);
	
	glEnd();


}

void COpenGLView::DrawHLS()
{
	static int i=180;
	glRotated(i,0,1,0);
	i+=1;

	GLfloat white[3]={0.0,1.0,0.0};
	GLfloat black[3]={0.0,-1.0,0.0};
	GLfloat red[3]={1.0,0.0,0.0};
	GLfloat yellow[3]={0.5,0.0,-0.866};
	GLfloat green[3]={-0.5,0.0,-0.866};
	GLfloat cyan[3]={-1.0,0.0,0.0};
	GLfloat blue[3]={-0.5,0.0,0.866};
	GLfloat magenta[3]={0.5,0.0,0.866};

	glBegin(GL_TRIANGLE_FAN);
	glColor3d(1,1,1);
	glVertex3fv(white);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glColor3d(1,1,0);
	glVertex3fv(yellow);
	glColor3d(0,1,0);
	glVertex3fv(green);
	glColor3d(0,1,1);
	glVertex3fv(cyan);
	glColor3d(0,0,1);
	glVertex3fv(blue);
	glColor3d(1,0,1);
	glVertex3fv(magenta);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glEnd();
	glBegin(GL_TRIANGLE_FAN);
	glColor3d(0,0,0);
	glVertex3fv(black);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glColor3d(1,1,0);
	glVertex3fv(yellow);
	glColor3d(0,1,0);
	glVertex3fv(green);
	glColor3d(0,1,1);
	glVertex3fv(cyan);
	glColor3d(0,0,1);
	glVertex3fv(blue);
	glColor3d(1,0,1);
	glVertex3fv(magenta);
	glColor3d(1,0,0);
	glVertex3fv(red);
	glEnd();

	glColor3d(0,0,0);

	glBegin(GL_LINE_STRIP);
	glVertex3fv(white);
	glVertex3fv(red);
	glVertex3fv(yellow);
	glVertex3fv(green);
	glVertex3fv(cyan);
	glVertex3fv(blue);
	glVertex3fv(magenta);
	glVertex3fv(red);
	glEnd();
	glScalef(1.005,1.005,1.005);
	glBegin(GL_LINES);
	glVertex3fv(black);
	glVertex3fv(red);
	glVertex3fv(black);
	glVertex3fv(yellow);
	glVertex3fv(black);
	glVertex3fv(green);
	glVertex3fv(black);
	glVertex3fv(cyan);
	glVertex3fv(black);
	glVertex3fv(blue);
	glVertex3fv(black);
	glVertex3fv(magenta);
	glVertex3fv(white);
	glVertex3fv(red);
	glVertex3fv(white);
	glVertex3fv(yellow);
	glVertex3fv(white);
	glVertex3fv(green);
	glVertex3fv(white);
	glVertex3fv(cyan);
	glVertex3fv(white);
	glVertex3fv(blue);
	glVertex3fv(white);
	glVertex3fv(magenta);
	glEnd();

}

void COpenGLView::DrawRGBCube()
{
	//glTranslatef(-0.5,-0.5,-0.5);

	GLfloat v1[3]={1.0,1.0,1.0};
	GLfloat v2[3]={1.0,1.0,0.0};
	GLfloat v3[3]={0.0,1.0,0.0};
	GLfloat v4[3]={0.0,1.0,1.0};
	GLfloat v5[3]={1.0,0.0,1.0};
	GLfloat v6[3]={1.0,0.0,0.0};
	GLfloat v7[3]={0.0,0.0,0.0};
	GLfloat v8[3]={0.0,0.0,1.0};

	float u,v, delta_u=0.02f,delta_v=0.02f;

	::glBegin(GL_QUADS); // each pair of glVertex will form a line
	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v4);
	glVertex3fv(v4);

	glColor3fv(v5);
	glVertex3fv(v5);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v7);
	glVertex3fv(v7);
	glColor3fv(v8);
	glVertex3fv(v8);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v5);
	glVertex3fv(v5);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v4);
	glVertex3fv(v4);
	glColor3fv(v8);
	glVertex3fv(v8);
	glColor3fv(v5);
	glVertex3fv(v5);

	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v4);
	glVertex3fv(v4);
	glColor3fv(v8);
	glVertex3fv(v8);
	glColor3fv(v7);
	glVertex3fv(v7);

	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v7);
	glVertex3fv(v7);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v5);
	glVertex3fv(v5);
	::glEnd();

	glScalef(1.005,1.005,1.005);
	glBegin(GL_LINE_STRIP);
	glColor3d(0,0,0);
	glVertex3fv(v1);
	glVertex3fv(v2);
	glVertex3fv(v3);
	glVertex3fv(v4);
	glVertex3fv(v1);
	glVertex3fv(v5);
	glVertex3fv(v6);
	glVertex3fv(v7);
	glVertex3fv(v8);
	glVertex3fv(v5);
	glEnd();

	glBegin(GL_LINES);
	glVertex3fv(v2);
	glVertex3fv(v6);
	glVertex3fv(v3);
	glVertex3fv(v7);
	glVertex3fv(v4);
	glVertex3fv(v8);
	glEnd();

}void COpenGLView::DrawRGB()
{
	static int i=180;
	
	glPushMatrix();
	glTranslatef(-0.8,-0.0,-0.0);
	glRotated(i,0,1,0);
	glTranslatef(-0.5,-0.5,-0.5);

	DrawRGBCube();
	glPopMatrix();

	glTranslatef(+0.8,-0.0,-0.0);
	glRotated(i,0,1,0);
	glTranslatef(-0.5,-0.5,-0.5);

	i+=1;
	GLfloat v1[3]={1.0,1.0,1.0};
	GLfloat v2[3]={1.0,0.5,0.0};
	GLfloat v3[3]={0.0,0.0,0.0};
	GLfloat v4[3]={0.0,0.5,1.0};
	GLfloat v5[3]={1.0,0.0,1.0};
	GLfloat v6[3]={1.0,0.0,0.0};
	GLfloat v7[3]={0.0,0.0,0.0};
	GLfloat v8[3]={0.0,0.0,1.0};

	float u,v, delta_u=0.02f,delta_v=0.02f;

	::glBegin(GL_QUADS); // each pair of glVertex will form a line
	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v4);
	glVertex3fv(v4);

	glColor3fv(v5);
	glVertex3fv(v5);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v7);
	glVertex3fv(v7);
	glColor3fv(v8);
	glVertex3fv(v8);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v5);
	glVertex3fv(v5);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v4);
	glVertex3fv(v4);
	glColor3fv(v8);
	glVertex3fv(v8);
	glColor3fv(v5);
	glVertex3fv(v5);

	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v4);
	glVertex3fv(v4);
	glColor3fv(v8);
	glVertex3fv(v8);
	glColor3fv(v7);
	glVertex3fv(v7);

	glColor3fv(v3);
	glVertex3fv(v3);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v7);
	glVertex3fv(v7);

	glColor3fv(v1);
	glVertex3fv(v1);
	glColor3fv(v2);
	glVertex3fv(v2);
	glColor3fv(v6);
	glVertex3fv(v6);
	glColor3fv(v5);
	glVertex3fv(v5);
	::glEnd();

	glScalef(1.005,1.005,1.005);
	glBegin(GL_LINE_STRIP);
	glColor3d(0,0,0);
	glVertex3fv(v1);
	glVertex3fv(v2);
	glVertex3fv(v3);
	glVertex3fv(v4);
	glVertex3fv(v1);
	glVertex3fv(v5);
	glVertex3fv(v6);
	glVertex3fv(v7);
	glVertex3fv(v8);
	glVertex3fv(v5);
	glEnd();

	glBegin(GL_LINES);
	glVertex3fv(v2);
	glVertex3fv(v6);
	glVertex3fv(v3);
	glVertex3fv(v7);
	glVertex3fv(v4);
	glVertex3fv(v8);
	glEnd();


}

void COpenGLView::OnMENUHLS() 
{
	// TODO: Add your command handler code here
	object=hls;	
	InvalidateRect(0,FALSE);
	GetParent()->PostMessage(WM_PAINT);

}

void COpenGLView::OnUpdateMENUHLS(CCmdUI* pCmdUI) 
{
	// TODO: Add your command update UI handler code here
	if(object==hls)
			pCmdUI->SetCheck();
	else
			pCmdUI->SetCheck(false);

}

void COpenGLView::OnMENUHSV() 
{
	// TODO: Add your command handler code here
	object=hsv;
	InvalidateRect(0,FALSE);
	GetParent()->PostMessage(WM_PAINT);

}

void COpenGLView::OnUpdateMENUHSV(CCmdUI* pCmdUI) 
{
	// TODO: Add your command update UI handler code here
	if(object==hsv)
			pCmdUI->SetCheck();
	else
			pCmdUI->SetCheck(false);
	
}

void COpenGLView::OnMENURGB() 
{
	// TODO: Add your command handler code here
	object=rgb;
	InvalidateRect(0,FALSE);
	GetParent()->PostMessage(WM_PAINT);
	
}

void COpenGLView::OnUpdateMENURGB(CCmdUI* pCmdUI) 
{
	// TODO: Add your command update UI handler code here
	if(object==rgb)
			pCmdUI->SetCheck();
	else
			pCmdUI->SetCheck(false);
	
}

void COpenGLView::OnRotate() 
{
	// TODO: Add your command handler code here
	rotating=!rotating;
	InvalidateRect(0,FALSE);
	GetParent()->PostMessage(WM_PAINT);

	
}

void COpenGLView::OnUpdateRotate(CCmdUI* pCmdUI) 
{
	// TODO: Add your command update UI handler code here
	if(rotating)
			pCmdUI->SetCheck();
	else
			pCmdUI->SetCheck(false);
	
}



void COpenGLView::OnLButtonDown(UINT nFlags, CPoint point) 
{
	// TODO: Add your message handler code here and/or call default
	dragging=true;
	last=point;
	this->SetCapture();
	CView::OnLButtonDown(nFlags, point);
}

void COpenGLView::OnMouseMove(UINT nFlags, CPoint point) 
{
	// TODO: Add your message handler code here and/or call default
	if(dragging){
		angle-=(last.y-point.y)/3;
		last=point;
	}
	CView::OnMouseMove(nFlags, point);
}
